@@ -1,17 +1,23 @@
 __all__ = [
+    "HPO",
     "PINN",
-    "Uniform",
+    "R3Sampling",
+    "RAD",
     "Random_R",
     "RAR_D",
     "RAR_G",
-    "RAD",
-    "R3Sampling",
+    "Uniform",
+    "gPINN",
+    "FBPINN",
 ]
 
+from .HPO import HPO
 from .PINN import PINN
-from .Uniform import Uniform
+from .R3Sampling import R3Sampling
+from .RAD import RAD
 from .Random_R import Random_R
 from .RAR_D import RAR_D
 from .RAR_G import RAR_G
-from .RAD import RAD
-from .R3Sampling import R3Sampling
\ No newline at end of file
+from .Uniform import Uniform
+from .gPINN import gPINN
+from .FBPINN import FBPINN
